SET NOCOUNT ON

/***********************************************/
/***************** Table Creation **************/
/***********************************************/
IF OBJECT_ID('dbo.Person', 'U') IS NOT NULL
BEGIN
	PRINT 'Recreating table Person'
	DROP TABLE dbo.Person
END

CREATE TABLE Person
( 
	Name			VARCHAR(100),
	SocialSecurity	VARCHAR(100),
	Age				INT
)


IF OBJECT_ID('dbo.Asset', 'U') IS NOT NULL
BEGIN
	PRINT 'Recreating table Asset'
	DROP TABLE dbo.Asset
END

CREATE TABLE Asset
(
	SocialSecurity	VARCHAR(100),
	AssetName		VARCHAR(100)
)


/***********************************************/
/***************** Insert Data *****************/
/***********************************************/
DECLARE @i INT
SET @i = 0

WHILE @i <> 2000
BEGIN

	INSERT INTO Person
	SELECT 
		CAST(NEWID() AS VARCHAR(100)), 
		CAST(NEWID() AS VARCHAR(100)),
		50
	FROM sys.dm_exec_sessions

	SET @i = @i + 1
	
	PRINT 'Counter: ' + CAST(@i AS VARCHAR(10))
END


INSERT INTO Asset
SELECT SocialSecurity, 'CAR' 
FROM Person

INSERT INTO Asset
SELECT TOP 10 PERCENT
	SocialSecurity, 'House'
FROM Person

INSERT INTO Asset
SELECT TOP 30 PERCENT
	SocialSecurity, '401k'
FROM Person


INSERT INTO Asset
SELECT TOP 75 PERCENT
	SocialSecurity, 'Television'
FROM Person

SELECT COUNT(*) Count FROM Asset

/***********************************************/
/***************** Create Indexes **************/
/***********************************************/
IF NOT EXISTS(SELECT * from sys.indexes WHERE name = 'Soc')
BEGIN
	CREATE NONCLUSTERED INDEX Soc ON dbo.Asset
	(
		SocialSecurity ASC
	)
END

/***********************************************/
/***************** Run Select Statements *******/
/***************** Start Profiler Trace Here ***/
/***********************************************/
select p.Name, p.SocialSecurity, p.Age, a.AssetName
from Person p
	INNER JOIN Asset a
		ON p.SocialSecurity = a.SocialSecurity
WHERE a.AssetName IN('CAR', 'Television')


SELECT p.Age, COUNT(a.AssetName)
FROM Person p
	INNER JOIN Asset a
		ON p.SocialSecurity = a.SocialSecurity
GROUP BY p.Age

SELECT p.Name, p.SocialSecurity, p.Age, a.AssetName
FROM Person p
	LEFT OUTER JOIN Asset a
		ON p.SocialSecurity = a.SocialSecurity
WHERE p.Name LIKE 'C%' 
ORDER BY p.SocialSecurity DESC


