/*****************************************************************************************************/
-- Error States If SniConsumerError = 18456:																					 																		 
--2 and 5 = Invalid User ID
--6 = Attempt to use a Windows login name with SQL authentication
--7 = Login disabled and password mismatch
--8 = Password mismatch
--9 = Invalid password
--11 and 12 = Valid login but server access failure
--13 = SQL Server service paused
--18 = Change password required
/*****************************************************************************************************/


SELECT
CONVERT (varchar(30), GETDATE(), 121) as [RunTime],
dateadd (ms, (rbf.[timestamp] - tme.ms_ticks), GETDATE()) as Time_Stamp,
cast(record as xml).value('(//Record/ConnectivityTraceRecord/RecordType)[1]', 'varchar(50)') AS [Action],
cast(record as xml).value('(//Record/ConnectivityTraceRecord/RecordSource)[1]', 'varchar(50)') AS [Source],
cast(record as xml).value('(//Record/ConnectivityTraceRecord/SniConnectionId)[1]', 'varchar(50)') AS SniConnectionId,
cast(record as xml).value('(//Record/ConnectivityTraceRecord/SniConsumerError)[1]', 'varchar(50)') AS SniConsumerError,
'State' = 
	CASE cast(record as xml).value('(//Record/ConnectivityTraceRecord/State)[1]', 'varchar(50)') 

		WHEN 2 THEN 'Invalid User ID'
		WHEN 5 THEN 'Invalid User ID'
		WHEN 6 THEN 'Attempt to use a Windows login name with SQL authentication'
		WHEN 7 THEN 'Login disabled and password mismatch'
		WHEN 8 THEN 'Invalid Password'
		WHEN 11 THEN 'Valid login but server access failure'
		WHEN 12 THEN 'Valid login but server access failure'
		WHEN 13 THEN 'SQL Server paused'
		WHEN 18 THEN 'Change password required'
		ELSE cast(record as xml).value('(//Record/ConnectivityTraceRecord/State)[1]', 'varchar(50)') 
	END, 
cast(record as xml).value('(//Record/ConnectivityTraceRecord/SniProvider)[1]', 'varchar(50)') AS SniProvider,
cast(record as xml).value('(//Record/ConnectivityTraceRecord/Spid)[1]', 'int') AS [SPID],
cast(record as xml).value('(//Record/ConnectivityTraceRecord/RemoteHost)[1]', 'varchar(100)') AS [RemoteHost],
cast(record as xml).value('(//Record/ConnectivityTraceRecord/RemotePort)[1]', 'varchar(25)') AS [RemotePort],
cast(record as xml).value('(//Record/ConnectivityTraceRecord/LocalPort)[1]', 'varchar(25)') AS [LocalPort],
cast(record as xml).value('(//Record/ConnectivityTraceRecord/TdsBuffersInformation/TdsInputBufferError)[1]', 'varchar(25)') AS [TdsInputBufferError],
cast(record as xml).value('(//Record/ConnectivityTraceRecord/TdsBuffersInformation/TdsOutputBufferError)[1]', 'varchar(25)') AS [TdsOutputBufferError],
cast(record as xml).value('(//Record/ConnectivityTraceRecord/TdsBuffersInformation/TdsInputBufferBytes)[1]', 'varchar(25)') AS [TdsInputBufferBytes],
cast(record as xml).value('(//Record/ConnectivityTraceRecord/TdsDisconnectFlags/PhysicalConnectionIsKilled)[1]', 'int') AS [isPhysConnKilled],
cast(record as xml).value('(//Record/ConnectivityTraceRecord/TdsDisconnectFlags/DisconnectDueToReadError)[1]', 'int') AS [DisconnectDueToReadError],
cast(record as xml).value('(//Record/ConnectivityTraceRecord/TdsDisconnectFlags/NetworkErrorFoundInInputStream)[1]', 'int') AS [NetworkErrorFound],
cast(record as xml).value('(//Record/ConnectivityTraceRecord/TdsDisconnectFlags/ErrorFoundBeforeLogin)[1]', 'int') AS [ErrorBeforeLogin],
cast(record as xml).value('(//Record/ConnectivityTraceRecord/TdsDisconnectFlags/SessionIsKilled)[1]', 'int') AS [isSessionKilled],
cast(record as xml).value('(//Record/ConnectivityTraceRecord/TdsDisconnectFlags/NormalDisconnect)[1]', 'int') AS [NormalDisconnect],
cast(record as xml).value('(//Record/ConnectivityTraceRecord/TdsDisconnectFlags/NormalLogout)[1]', 'int') AS [NormalLogout],
cast(record as xml).value('(//Record/ConnectivityTraceRecord/LoginTimers/TotalLoginTimeInMilliseconds)[1]', 'int') AS [TotalLoginTimeInMilliseconds],
cast(record as xml).value('(//Record/ConnectivityTraceRecord/LoginTimers/LoginTaskEnqueuedInMilliseconds)[1]', 'int') AS [LoginTaskEnqueuedInMilliseconds],
cast(record as xml).value('(//Record/ConnectivityTraceRecord/LoginTimers/NetworkWritesInMilliseconds)[1]', 'int') AS [NetworkWritesInMilliseconds],
cast(record as xml).value('(//Record/ConnectivityTraceRecord/LoginTimers/NetworkReadsInMilliseconds)[1]', 'int') AS [NetworkReadsInMilliseconds],
cast(record as xml).value('(//Record/ConnectivityTraceRecord/LoginTimers/SslProcessingInMilliseconds)[1]', 'int') AS [SslProcessingInMilliseconds],
cast(record as xml).value('(//Record/ConnectivityTraceRecord/LoginTimers/SspiProcessingInMilliseconds)[1]', 'int') AS [SspiProcessingInMilliseconds],
cast(record as xml).value('(//Record/ConnectivityTraceRecord/LoginTimers/LoginTriggerAndResourceGovernorProcessingInMilliseconds)[1]', 'int') AS [LoginTriggerAndResourceGovernorProcessingInMilliseconds],
cast(record as xml).value('(//Record/@id)[1]', 'bigint') AS [Record Id],
cast(record as xml).value('(//Record/@type)[1]', 'varchar(30)') AS [Type],
cast(record as xml).value('(//Record/@time)[1]', 'bigint') AS [Record Time],
tme.ms_ticks as [Current Time]
FROM sys.dm_os_ring_buffers rbf
cross join sys.dm_os_sys_info tme
WHERE
rbf.ring_buffer_type = 'RING_BUFFER_CONNECTIVITY'
AND CAST(record as xml).value('(//Record/ConnectivityTraceRecord/Spid)[1]', 'int') <>0
AND CAST(record as xml).value('(//Record/ConnectivityTraceRecord/SniConsumerError)[1]', 'varchar(50)') = 18456
ORDER BY [Record Id] DESC


--Alternative approach
--Place the "record" portion of this in an xml file and open it with any type of modern internet browser

--SELECT * FROM sys.dm_os_ring_buffers 
--WHERE ring_buffer_type = 'RING_BUFFER_CONNECTIVITY'
--ORDER BY  timestamp desc
